@@ -5,7 +5,7 @@ use warnings;
 require Test::More;
 require Exporter;
 our @ISA = qw(Exporter);
-our @EXPORT = qw(is_approx histo_eq);
+our @EXPORT = qw(is_approx histo_eq histo_eq_test_no);
 
 sub is_approx {
   my $delta = $_[3] || 1e-9;
@@ -14,6 +14,8 @@ sub is_approx {
 }
 
 
+sub histo_eq_test_no { 11 + scalar(@{$_[0]->bin_centers})*2 }
+
 sub histo_eq {
   my ($ref, $test, $name) = @_;
   $name = "hist. compare" if not defined $name;
@@ -28,10 +30,17 @@ sub histo_eq {
   is_approx($test->width, $ref->width, "width is the same ($name)");
   is_approx($test->binsize, $ref->binsize, "binsize is the same ($name)");
 
-  Test::More::is_deeply($test->all_bin_contents, $ref->all_bin_contents, "data is the same ($name)");
-  Test::More::is_deeply($test->bin_centers, $ref->bin_centers, "bin centers are the same ($name)");
+  my $ref_content = $ref->all_bin_contents();
+  my $ref_centers = $ref->bin_centers();
+  my $test_content = $test->all_bin_contents();
+  my $test_centers = $test->bin_centers();
+  Test::More::is(scalar(@$ref_content), scalar(@{$test->all_bin_contents()}), "No. of bins with content correct ($name)");
+  Test::More::is(scalar(@$ref_centers), scalar(@{$test->bin_centers()}), "No. of bin centers correct ($name)");
+  foreach my $i (0..$ref->nbins-1) {
+    is_approx($test_content->[$i], $ref_content->[$i], "Bin content bin $i ($name)");
+    is_approx($test_centers->[$i], $ref_centers->[$i], "Bin center bin $i ($name)");
+  }
 }
 
-
 1;
 
